<?php

namespace Drupal\animate\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings class for animate.
 */
class AnimateSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'animate.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'animate_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    // Enable library globally.
    $form['enable_globally'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable animate globally.'),
      '#description' => $this->t('Enables animate library globally using hook_page_attachments.'),
      '#default_value' => $config->get('enable_globally'),
    ];

    // Enable CDN.
    $form['cdn'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable CDN.'),
      '#description' => $this->t('Get libraries from cdn.'),
      '#default_value' => $config->get('cdn'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save animate settings.
    $this->config(static::SETTINGS)
      ->set('enable_globally', $form_state->getValue('enable_globally'))
      ->set('cdn', $form_state->getValue('cdn'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
