<?php

namespace Drupal\animate\Plugin\field_group\FieldGroupFormatter;

use Drupal\animate\Animate;
use Drupal\field_group\Plugin\field_group\FieldGroupFormatter\HtmlElement;

/**
 * Plugin implementation of the 'animated_html_element' formatter.
 *
 * @FieldGroupFormatter(
 *   id = "animated_html_element",
 *   label = @Translation("Animated HTML element"),
 *   description = @Translation("This fieldgroup renders the inner content in a
 *   HTML element with classes and attributes and some animation."),
 *   supported_contexts = {
 *     "form",
 *     "view",
 *   }
 * )
 */
class AnimatedHtmlElement extends HtmlElement {

  /**
   * {@inheritdoc}
   */
  public function process(&$element, $processed_object) {

    // Keep using preRender parent for BC.
    parent::process($element, $processed_object);

    $attributes = &$element['#attributes'];

    // Adding effect.
    if (!empty($this->getSetting('effect')) ||
      $this->getSetting('effect') != 'none') {
      $attributes->setAttribute('data-animation', 'animate__' . $this->getSetting('effect'));
    }

    // Add speed.
    $attributes->setAttribute('data-speed', $this->getSetting('speed'));

    // Add animated class.
    $attributes->addClass('animate__animated');

    // Add object type.
    $element['#objectType'] = 'animated_html_element';

    // Add animation library if not already added.
    if (!animate_is_global()) {
      $element['#attached']['library'][] = animate_get_library();
    }

  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    // Build parent form.
    $form = parent::settingsForm();
    // Unset speed key.
    if (array_key_exists('speed', $form)) {
      unset($form['speed']);
    }
    // Unset effect key.
    if (array_key_exists('effect', $form)) {
      unset($form['effect']);
    }
    // Add effect item back with animation.
    $anim_classes = Animate::getAnimationClasses();
    $form['effect'] = [
      '#title' => $this->t('Effect'),
      '#type' => 'select',
      '#options' => $anim_classes,
      '#default_value' => $this->getSetting('effect'),
      '#weight' => 6,
      '#attributes' => [
        'data-fieldgroup-selector' => 'effect',
      ],
    ];

    return $form;
  }

}
